<?php

namespace App\Http\Controllers;

use App\Book_lend;
use App\Books;
use App\Publishers;
use App\Writers;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use DB;

class BookController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
      $books = Books::select('books.*', 'a.name as writerName', 'b.name as translator', 'publishers.name as publisherName')
          ->join('writers as a', 'books.writer', '=', 'a.id')
          ->join('writers as b', 'books.translator', '=', 'b.id', 'left outer')
          ->join('publishers', 'books.publisher', '=', 'publishers.id')
          ->orderby('id', 'asc')->get();
        $writers = Writers::select('*')->orderby('name', 'asc')->get();
        $publishers = Publishers::select('*')->orderby('name', 'asc')->get();

        // echo "<pre>";
        // print_r($books);
        // echo "</pre>";exit;
        return view('books.book',['books'=>$books,'writers'=>$writers,'publishers'=>$publishers])->with('message','');

    }

    public function wishlist()
    {
        $books = Books::select('books.*', 'a.name as writerName', 'b.name as translator', 'publishers.name as publisherName')
            ->join('writers as a', 'books.writer', '=', 'a.id')
            ->join('writers as b', 'books.translator', '=', 'b.id', 'left outer')
            ->join('publishers', 'books.publisher', '=', 'publishers.id')
            ->where('status', '=', '3')
            ->orderby('id', 'asc')->get();

        $writers = Writers::select('*')->orderby('name', 'asc')->get();
        $publishers = Publishers::select('*')->orderby('name', 'asc')->get();

        return view('books.wishlist',['books'=>$books,'writers'=>$writers,'publishers'=>$publishers])->with('message','');

    }

    public function lend()
    {
        $books = Books::select('books.*', 'a.name as writerName', 'b.name as translator', 'publishers.name as publisherName')
            ->join('writers as a', 'books.writer', '=', 'a.id')
            ->join('writers as b', 'books.translator', '=', 'b.id', 'left outer')
            ->join('publishers', 'books.publisher', '=', 'publishers.id')
            ->orderby('id', 'asc')->get();

        $lend = Book_lend::select('book_lend.*', 'books.name')
            ->join('books', 'book_lend.book_id', '=', 'books.id')
            ->where('book_lend.status','taken')
            ->get();
        $writers = Writers::select('*')->orderby('name', 'asc')->get();
        $publishers = Publishers::select('*')->orderby('name', 'asc')->get();

        return view('books.lend',['lend'=>$lend,'books'=>$books,'writers'=>$writers,'publishers'=>$publishers])->with('message','');

    }


    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {

        $this->validate($request,[
            'name'             => 'required',
        ]);

        $bookInfo = new Books();
        $bookInfo->name = $request->name;
        $bookInfo->writer = $request->writer;
        $bookInfo->translator = $request->translator;
        $bookInfo->publisher = $request->publisher;
        $bookInfo->edition = $request->edition;
        $bookInfo->publish_date = $request->publish_date;
        $bookInfo->purchase_date = $request->purchase_date;
        $bookInfo->price = $request->price;
        $bookInfo->subject = $request->subject;
        $bookInfo->status = $request->status;
        $bookInfo->isbn = $request->isbn;
        $bookInfo->tags = $request->tags;

        $bookInfo->save();

        return redirect('/book')->with('message','Data Saved successfully!');
    }


    public function search(Request $request){
        //return dd($id);
        $tags = $request->search;
        $tags = "%".str_replace(" ","%", $tags)."%";

        $booksInfo = Books::select('books.*', 'writers.name as writerName', 'publishers.name as publisherName')
            ->join('writers', 'books.writer', '=', 'writers.id')
            ->join('publishers', 'books.publisher', '=', 'publishers.id')
            ->where('books.tags','like', $tags)
            ->get();

        return view('books.bookSearch',['books'=>$booksInfo]);
    }

    public function showById($id){
        $booksInfo = Books::select('books.*', 'a.name as writerName', 'b.name as translator', 'publishers.name as publisherName')
            ->join('writers as a', 'books.writer', '=', 'a.id')
            ->join('writers as b', 'books.translator', '=', 'b.id', 'left outer')
            ->join('publishers', 'books.publisher', '=', 'publishers.id')
            ->where('books.id',$id)
            ->first();

        return view('books.bookShowById',['booksInfo'=>$booksInfo]);
    }

    public function editById($id){
        $booksInfo = Books::select('*')->orderby('created_at', 'desc')
            ->where('id',$id)
            ->first();

        $writers = Writers::select('*')->orderby('name', 'asc')->get();
        $publishers = Publishers::select('*')->orderby('name', 'asc')->get();

        return view('books.bookEditById',['booksInfo'=>$booksInfo,'writers'=>$writers,'publishers'=>$publishers]);
    }

    public function editLendById($id){
        $lendInfo = Book_lend::select('*')
            ->where('book_id',$id)
            ->first();

        $booksInfo = Books::select('*')
            ->where('id',$id)
            ->first();

        $writers = Writers::select('*')->orderby('name', 'asc')->get();
        $publishers = Publishers::select('*')->orderby('name', 'asc')->get();

        return view('books.lendEditById',['lendInfo'=>$lendInfo,'booksInfo'=>$booksInfo,'writers'=>$writers,'publishers'=>$publishers]);
    }

    /*
     * Lend books
     * param: id
     * */
    public function lendById($id){
        $booksInfo = Books::select('*')->orderby('created_at', 'desc')
            ->where('id',$id)
            ->first();

        $writers = Writers::select('*')->orderby('name', 'asc')->get();
        $publishers = Publishers::select('*')->orderby('name', 'asc')->get();

        return view('books.bookLendById',['booksInfo'=>$booksInfo,'writers'=>$writers,'publishers'=>$publishers]);
    }

    public function lendBookById(Request $request){
        $this->validate($request,[
            'borrower_name'             => 'required',
        ]);

        $bookInfo = new Book_lend();
        $bookInfo->book_id = $request->id;
        $bookInfo->borrower = $request->borrower_name;
        $bookInfo->address = $request->address;
        $bookInfo->contact_no = $request->contact_no;
        $bookInfo->borrow_date = $request->borrow_date;
        $bookInfo->return_date = $request->return_date;
        $bookInfo->status = $request->status;
        $bookInfo->given_by = Auth::id();
        $bookInfo->save();

        DB::table('books')
            ->where('id', $request->id)
            ->update([
                'status' => 2,
            ]);


        return redirect('/book')->with('message','Data Saved successfully!');
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function updateById(Request $request)
    {

        $this->validate($request,[
            'name'             => 'required',
        ]);
        //echo $tags;die;
        DB::table('books')
            ->where('id', $request->id)
            ->update([
                'name' => $request->name,
                'writer' => $request->writer,
                'translator' => $request->translator,
                'publisher' => $request->publisher,
                'edition' => $request->edition,
                'publish_date' => $request->publish_date,
                'purchase_date' => $request->purchase_date,
                'price' => $request->price,
                'subject' => $request->subject,
                'status' => $request->status,
                'tags' => $request->tags,
                'isbn' => $request->isbn,
            ]);

        return redirect('/book')->with('message','Data Updated Successfully!');
    }

    public function updateLendById(Request $request)
    {

        $this->validate($request,[
            'name'             => 'required',
        ]);
        $status = $request->status;
        DB::table('book_lend')
            ->where('id', $request->id)
            ->update([
                'borrower' => $request->borrower_name,
                'address' => $request->address,
                'contact_no' => $request->contact_no,
                'borrow_date' => $request->borrow_date,
                'return_date' => $request->return_date,
                'status' => $status
            ]);
        $b_status = ($status == "returned")?1:2;
        DB::table('books')
            ->where('id', $request->book_id)
            ->update([
                'status' => $b_status
            ]);

        return redirect('/lend')->with('message','Data Updated Successfully!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        DB::table('books')
            ->where('id', $id)
            ->delete();
        return redirect('/book')->with('message','Data successfully deleted!');

    }
    
    public function showBookshelfPage(){
        $books = array();



        $book1  = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'অ%')->get();
        $book2  = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'আ%')->get();
        $book3  = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ই%')->get();
        $book4  = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ঈ%')->get();
        $book5  = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'উ%')->get();
        $book6  = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ঊ%')->get();
        $book7  = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ঋ%')->get();
        $book8  = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'এ%')->get();
        $book9  = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ঐ%')->get();
        $book10 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ও%')->get();
        $book11 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ঔ%')->get();
        $book12 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ক%')->get();
        $book13 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'খ%')->get();
        $book14 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'গ%')->get();
        $book15 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ঘ%')->get();
        $book16 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ঙ%')->get();
        $book17 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'চ%')->get();
        $book18 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ছ%')->get();
        $book19 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'জ%')->get();
        $book20 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ঝ%')->get();
        $book21 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ঞ%')->get();
        $book22 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ট%')->get();
        $book23 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ঠ%')->get();
        $book24 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ড%')->get();
        $book25 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ঢ%')->get();
        $book26 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ণ%')->get();
        $book27 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ত%')->get();
        $book28 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'থ%')->get();
        $book29 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'দ%')->get();
        $book30 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ধ%')->get();
        $book31 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ন%')->get();
        $book32 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'প%')->get();
        $book33 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ফ%')->get();
        $book34 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ব%')->get();
        $book35 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ভ%')->get();
        $book36 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ম%')->get();
        $book37 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'য%')->get();
        $book38 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'র%')->get();
        $book39 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ল%')->get();
        $book40 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'শ%')->get();
        $book41 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ষ%')->get();
        $book42 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'স%')->get();
        $book43 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'হ%')->get();
        $book44 = Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ড়%')->get();
        $book45= Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'ঢ়%')->get();
        $book46= Books::select('id', 'isbn as book_id','name as book_name')->where('name', 'LIKE', 'য়%')->get();



        array_push($books, array('rec'=>'অ',  'book'=>$book1));
        array_push($books, array('rec'=>'আ',  'book'=>$book2));
        array_push($books, array('rec'=>'ই',  'book'=>$book3));
        array_push($books, array('rec'=>'ঈ',  'book'=>$book4));
        array_push($books, array('rec'=>'উ',  'book'=>$book5));
        array_push($books, array('rec'=>'ঊ',  'book'=>$book6));
        array_push($books, array('rec'=>'ঈ',  'book'=>$book7));
        array_push($books, array('rec'=>'এ',  'book'=>$book8));
        array_push($books, array('rec'=>'ঐ',  'book'=>$book9));
        array_push($books, array('rec'=>'ও',  'book'=>$book10));
        array_push($books, array('rec'=>'ঔ',  'book'=>$book11));
        array_push($books, array('rec'=>'ক',  'book'=>$book12));
        array_push($books, array('rec'=>'খ',  'book'=>$book13));
        array_push($books, array('rec'=>'গ',  'book'=>$book14));
        array_push($books, array('rec'=>'ঘ',  'book'=>$book15));
        array_push($books, array('rec'=>'ঙ',  'book'=>$book16));
        array_push($books, array('rec'=>'চ',  'book'=>$book17));
        array_push($books, array('rec'=>'ছ',  'book'=>$book18));
        array_push($books, array('rec'=>'জ',  'book'=>$book19));
        array_push($books, array('rec'=>'ঝ',  'book'=>$book20));
        array_push($books, array('rec'=>'ঞ',  'book'=>$book21));
        array_push($books, array('rec'=>'ট',  'book'=>$book22));
        array_push($books, array('rec'=>'ঠ',  'book'=>$book23));
        array_push($books, array('rec'=>'ড',  'book'=>$book24));
        array_push($books, array('rec'=>'ঢ',  'book'=>$book25));
        array_push($books, array('rec'=>'ণ',  'book'=>$book26));
        array_push($books, array('rec'=>'ত',  'book'=>$book27));
        array_push($books, array('rec'=>'থ',  'book'=>$book28));
        array_push($books, array('rec'=>'দ',  'book'=>$book29));
        array_push($books, array('rec'=>'ধ',  'book'=>$book30));
        array_push($books, array('rec'=>'ন',  'book'=>$book31));
        array_push($books, array('rec'=>'প',  'book'=>$book32));
        array_push($books, array('rec'=>'ফ',  'book'=>$book33));
        array_push($books, array('rec'=>'ব',  'book'=>$book34));
        array_push($books, array('rec'=>'ভ',  'book'=>$book35));
        array_push($books, array('rec'=>'ম',  'book'=>$book36));
        array_push($books, array('rec'=>'য',  'book'=>$book37));
        array_push($books, array('rec'=>'র',  'book'=>$book38));
        array_push($books, array('rec'=>'ল',  'book'=>$book39));
        array_push($books, array('rec'=>'শ',  'book'=>$book40));
        array_push($books, array('rec'=>'ষ',  'book'=>$book41));
        array_push($books, array('rec'=>'স',  'book'=>$book42));
        array_push($books, array('rec'=>'হ',  'book'=>$book43));
        array_push($books, array('rec'=>'ড়',  'book'=>$book44));
        array_push($books, array('rec'=>'ঢ়',  'book'=>$book45));
        array_push($books, array('rec'=>'য়',  'book'=>$book46));

        //echo "<pre>";
        //print_r($books);
        //echo "</pre>";die;
        //return view('web.bookshelf', compact('book1', 'book2', 'book3', 'book4', 'book5', 'book6', 'book7', 'book8', 'book9', 'book10', 'book11', 'book12', 'book13', 'book14', 'book15', 'book16', 'book17', 'book18', 'book19', 'book20', 'book21', 'book22', 'book23', 'book24', 'book25'));
        return view('books.bookshelf', compact('books'));
    }
}
